pub struct Address(/* private fields */);Expand description
Represents an Ethereum address
Implementations
Sourceimpl Address
impl Address
Sourcepub fn new(bytes: &[u8]) -> Address
pub fn new(bytes: &[u8]) -> Address
Creates a new Address from the given byte slice.
Panics
Panics if bytes length is not equal to Address::SIZE (20 bytes).
Sourcepub fn to_bytes32(&self) -> Box<[u8]>
pub fn to_bytes32(&self) -> Box<[u8]>
Converts this 20-byte address into a 32-byte ABI-encoded representation by left-padding with 12 zero bytes.
Sourcepub fn to_checksum(&self) -> String
pub fn to_checksum(&self) -> String
Turns the address into a checksum-ed address string according to EIP-55.